===============================
Tool Grid Widget (``toolgrid``)
===============================

.. automodule:: orangecanvas.gui.toolgrid

.. autoclass:: orangecanvas.gui.toolgrid.ToolGrid
   :members:
   :member-order: bysource
   :exclude-members:
      actionTriggered,
      actionHovered
   :show-inheritance:

   .. autoattribute:: actionTriggered(QAction)

      Signal emitted when an action is triggered.

   .. autoattribute:: actionHovered(QAction)

      Signal emitted when an action is hovered.
